# Usage

To see a list of available commands run:

```
twitch-dl --help
```

And to see description and all arguments for a given command run:

```
twitch-dl <command> --help
```

## Commands

Click on a command to see it's documentation.

|                                    |                                 |
|----------------------------------- | ------------------------------- |
| [`cache`](commands/cache.md)       | View and manage cached files.   |
| [`chat`](commands/chat.md)         | Render chat for a given video.  |
| [`clips`](commands/clips.md)       | List clips from a channel.      |
| [`download`](commands/download.md) | Download a video or clip.       |
| [`env`](commands/env.md)           | Print environment information.  |
| [`info`](commands/info.md)         | Print info for a video or clip. |
| [`videos`](commands/videos.md)     | List videos from a channel.     |
